Module helpers

Module helpers 

Structs

HardBlock
A soft block is a block that is not required to be on a new line.
KAndRBracket
K & R style brackets
PrettySequence
The document sequence type.
SoftBlock
A soft block is a block that is not required to be on a new line.