SoftBlock

Struct SoftBlock 

pub struct SoftBlock<'a, T> {
    pub indent: usize,
    pub lhs: &'static str,
    pub rhs: &'static str,
    pub joint: PrettyTree<'a, T>,
    pub tail: PrettyTree<'a, T>,
}
A soft block is a block that is not required to be on a new line.

{a, b, c}

{
    a,
    b,
}

Fields

indent: usize

The indentation of the soft block

lhs: &'static str

The left hand side of the soft block

rhs: &'static str

The right hand side of the soft block

joint: PrettyTree<'a, T>

The joint node of the soft block

tail: PrettyTree<'a, T>

The tail node of the soft block

Implementations

Source

impl<'a, T: Text<'a>> SoftBlock<'a, T>

pub fn new(lhs: &'static str, rhs: &'static str) -> Self

Build a new soft block

pub fn tuple() -> Self

Build a new soft block with the tuple syntax

pub fn parentheses() -> Self

Build a new soft block with the parentheses syntax

pub fn brackets() -> Self

Build a new soft block with the brackets syntax

pub fn curly_braces() -> Self

Build a new soft block with the curly braces syntax

pub fn with_joint(self, joint: PrettyTree<'a, T>) -> Self

Set the joint node of the soft block

Source

impl<'a, T: Text<'a> + Clone> SoftBlock<'a, T>

pub fn join_slice<U: PrettyPrint<'a, T>>( &self, slice: &[U], theme: &PrettyProvider, ) -> PrettyTree<'a, T>

Join a slice of pretty printables with the soft block