pub struct SoftBlock<'a, T> {
pub indent: usize,
pub lhs: &'static str,
pub rhs: &'static str,
pub joint: PrettyTree<'a, T>,
pub tail: PrettyTree<'a, T>,
}Expand description
A soft block is a block that is not required to be on a new line.
{a, b, c}
{
a,
b,
}Fields
indent: usizeThe indentation of the soft block
lhs: &'static strThe left hand side of the soft block
rhs: &'static strThe right hand side of the soft block
joint: PrettyTree<'a, T>The joint node of the soft block
tail: PrettyTree<'a, T>The tail node of the soft block
Implementations
Sourceimpl<'a, T: Text<'a>> SoftBlock<'a, T>
impl<'a, T: Text<'a>> SoftBlock<'a, T>
Sourcepub fn parentheses() -> Self
pub fn parentheses() -> Self
Build a new soft block with the parentheses syntax
Sourcepub fn curly_braces() -> Self
pub fn curly_braces() -> Self
Build a new soft block with the curly braces syntax
Sourcepub fn with_joint(self, joint: PrettyTree<'a, T>) -> Self
pub fn with_joint(self, joint: PrettyTree<'a, T>) -> Self
Set the joint node of the soft block
Sourceimpl<'a, T: Text<'a> + Clone> SoftBlock<'a, T>
impl<'a, T: Text<'a> + Clone> SoftBlock<'a, T>
Sourcepub fn join_slice<U: PrettyPrint<'a, T>>(
&self,
slice: &[U],
theme: &PrettyProvider,
) -> PrettyTree<'a, T>
pub fn join_slice<U: PrettyPrint<'a, T>>( &self, slice: &[U], theme: &PrettyProvider, ) -> PrettyTree<'a, T>
Join a slice of pretty printables with the soft block